const headElem = document.getElementById("head");
const buttonsElem = document.getElementById("buttons");
const pagesElem = document.getElementById("pages");


class Quiz
{
	constructor(type, questions, results)
	{
		this.type = type;
		this.questions = questions;
		this.results = results;
		this.score = 0;
		this.result = 0;
		this.current = 0;
	}

	Click(index)
	{
		let value = this.questions[this.current].Click(index);
		this.score += value;
		let correct = -1;
		if(value >= 1)
		{
			correct = index;
		}
		else
		{
			for(let i = 0; i < this.questions[this.current].answers.length; i++)
			{
				if(this.questions[this.current].answers[i].value >= 1)
				{
					correct = i;
					break;
				}
			}
		}
		this.Next();
		return correct;
	}


	Next()
	{
		this.current++;
		if(this.current >= this.questions.length) 
		{
			this.End();
		}
	}

	End()
	{
		for(let i = 0; i < this.results.length; i++)
		{
			if(this.results[i].Check(this.score))
			{
				this.result = i;
			}
		}
	}
} 


class Question 
{
	constructor(text, answers)
	{
		this.text = text; 
		this.answers = answers; 
	}
	Click(index) 
	{
		return this.answers[index].value; 
	}
}


class Answer 
{
	constructor(text, value) 
	{
		this.text = text; 
		this.value = value; 
	}
}


class Result 
{
	constructor(text, value)
	{
		this.text = text;
		this.value = value;
	}


	Check(value)
	{
		if(this.value <= value)
		{
			return true;
		}
		else 
		{
			return false;
		}
	}
}


const results = 
[
	new Result("УЖАС,Вы не сдали"),
	new Result("ПОЗДРАВЛЯЕМ, вы сдали тест", 7)
];

const questions = 
[
	new Question(`Привет! Это тест на знание киберспорта по дисциплине CS:GO, у тебя всего 20 секунд.  <br>
	И первый вопрос: Кто лучший АВАПЕР всех времен и народов?`, 
	[
		new Answer("Guardian", 0),
		new Answer("Solek", 0),
		new Answer("Markeloff", 1),
		new Answer("JW", 0)
	]),

	new Question("Какая самая титулованая СНГ команда? ", 
	[
		new Answer("Na'Vi", 1),
		new Answer("PRO100", 0),
		new Answer("Virtus.Pro", 0),
		new Answer("HellRaisers", 0)
	]),

	new Question("Если горит Молотов, то в него бежит... ", 
	[
		new Answer("Get-Right", 0),
		new Answer("Zeus", 1),
		new Answer("Simple", 0),
		new Answer("Adren", 0)
	]),

	new Question("Кто из старого состава Na'Vi был главным по нарезанию АРбуза? ", 
	[
		new Answer("Siezd", 1),
		new Answer("Zeus", 0),
		new Answer("Starix", 0),
		new Answer("Guardian", 0)
	]),

	new Question("Кто из ниже перечисленых играл в Американской организации?", 
	[
		new Answer("Flamie", 0),
		new Answer("Simple", 1),
		new Answer("Solek", 0),
		new Answer("iDisbalance", 0)
	]),

	new Question("В далеком 2014 году, кто был самым главным ваншотером?", 
	[
		new Answer("Dosia", 0),
		new Answer("Olofmaister", 0),
		new Answer("Scream", 1),
		new Answer("Edward", 0)
	]),

	new Question("Главный пистол-кинг - это...", 
	[
		new Answer("Xizt", 0),
		new Answer("Friberg", 0),
		new Answer("Edward", 1),
		new Answer("chrisJ", 0)
	]),

	new Question("В какой из этих команд не играл Adren?", 
	[
		new Answer("Gambit", 0),
		new Answer("AstanaDragons", 0),
		new Answer("PRO100", 1),
		new Answer("daT-Team", 0)
	]),

	new Question("Какой никнейм у Ярослава Яжомбковски?", 
	[
		new Answer("SANJI", 0),
		new Answer("STYKO", 0),
		new Answer("pashaBiceps", 1),
		new Answer("rain", 0)
	]),

	new Question("В какой команде сейчас играет Siezd?", 
	[
		new Answer("NiP", 0),
		new Answer("Virtus.Pro", 0),
		new Answer("Cyber Legacy", 1),
		new Answer("AstanaDragons", 0)
	])
];


const quiz = new Quiz(1, questions, results);

Update();


function Update()
{
	if(quiz.current < quiz.questions.length) 
	{
	
		headElem.innerHTML = quiz.questions[quiz.current].text;


		buttonsElem.innerHTML = "";


		for(let i = 0; i < quiz.questions[quiz.current].answers.length; i++)
		{
			let btn = document.createElement("button");
			btn.className = "button";

			btn.innerHTML = quiz.questions[quiz.current].answers[i].text;

			btn.setAttribute("index", i);

			buttonsElem.appendChild(btn);
		}
	
		pagesElem.innerHTML = (quiz.current + 1) + " / " + quiz.questions.length;
		Init();
	}
	else
	{
		buttonsElem.innerHTML =  '';
		headElem.innerHTML = quiz.results[quiz.result].text;
		pagesElem.innerHTML = "Очки: " + quiz.score;
	}
}
setInterval(function() {
	buttonsElem.innerHTML = '';
		headElem.innerHTML = quiz.results[quiz.result].text;
		pagesElem.innerHTML = "Очки: " + quiz.score;;
   }, 20000);

function Init()
{

	let btns = document.getElementsByClassName("button");

	for(let i = 0; i < btns.length; i++)
	{
		btns[i].addEventListener("click", function (e) { Click(e.target.getAttribute("index")); });
	}
}

function Click(index) 
{
	let correct = quiz.Click(index);
	let btns = document.getElementsByClassName("button");
	for(let i = 0; i < btns.length; i++)
	{
		btns[i].className = "button button_passive";
	}

	if(quiz.type == 1)
	{
		if(correct >= 0)
		{
			btns[correct].className = "button button_correct";
		}

		if(index != correct) 
		{
			btns[index].className = "button button_wrong";
		} 
	}
	else
	{
		btns[index].className = "button button_correct";
	}
	setTimeout(Update, 700);
}
